==> fuse-0.4.1.tar.gz: fuse-0.4.1/ui/fb/fbui.c <==
/* fbui.c: Routines for dealing with the linux fbdev user interface
   Copyright (c) 2000-2001 Philip Kendall, Matan Ziv-Av

   $Id: fbui.c,v 1.12 2001/12/27 21:44:08 pak21 Exp $

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

   Author contact information:

   E-mail: pak21-fuse@srcf.ucam.org
   Postal address: 15 Crescent Road, Wokingham, Berks, RG40 2DB, England

*/

#include <config.h>

#ifdef UI_FB			/* Use this iff we're using fbdev */

#include <stdio.h>

#include "fuse.h"
#include "fbkeyboard.h"
#include "ui/ui.h"
#include "ui/uidisplay.h"

int ui_init(int *argc, char ***argv, int width, int height)
{
  int error;

  error = uidisplay_init(width, height);
  if(error) return error;

  error = fbkeyboard_init();
  if(error) return error;

  return 0;
}

int ui_event()
{
  keyboard_update();
  return 0;
}

int ui_end(void)
{
  int error;

  error = fbkeyboard_end();
  if(error) return error;

  error = uidisplay_end();
  if(error) return error;

  return 0;
}

#endif				/* #ifdef UI_FB */

==> fuse-0.6.2.1.tar.gz: fuse-0.6.2.1/ui/fb/fbui.c <==
/* fbui.c: Routines for dealing with the linux fbdev user interface
   Copyright (c) 2000-2003 Philip Kendall, Matan Ziv-Av, Witold Filipczyk

   $Id: fbui.c,v 1.15 2003/04/13 09:47:36 pak21 Exp $

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

   Author contact information:

   E-mail: pak21-fuse@srcf.ucam.org
   Postal address: 15 Crescent Road, Wokingham, Berks, RG40 2DB, England

*/

#include <config.h>

#ifdef UI_FB			/* Use this iff we're using fbdev */

#include <stdlib.h>

#include "fbdisplay.h"
#include "fbkeyboard.h"
#include "ui/ui.h"
#include "ui/uidisplay.h"

static void fb_end( void );

int
ui_init( int *argc, char ***argv )
{
  int error;

  atexit( fb_end );

  error = fbkeyboard_init();
  if(error) return error;

  error = fbdisplay_init();
  if(error) return error;

  return 0;
}

int ui_event()
{
  keyboard_update();
  return 0;
}

int ui_end(void)
{
  /* Cleanup handled by atexit function */
  int error;
  
  error = fbkeyboard_end(); if( error ) return error;
  error = fbdisplay_end(); if( error ) return error;

  return 0;
}

static void
fb_end( void )
{
  fbkeyboard_end();
  uidisplay_end();
}

#endif				/* #ifdef UI_FB */
